==> jc-1.4.0.tar.gz: polyglot/util/ErrorInfo.h <==
// public class polyglot.util.ErrorInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1b61c050315c20e6 polyglot_util_ErrorInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_ErrorInfo_H_
#define _JC_polyglot_util_ErrorInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_ErrorInfo$sub_refs	_jc_polyglot_util_ErrorInfo$sub_refs;
typedef struct _jc_polyglot_util_ErrorInfo$sub_nonrefs	_jc_polyglot_util_ErrorInfo$sub_nonrefs;
typedef struct _jc_polyglot_util_ErrorInfo$refs	_jc_polyglot_util_ErrorInfo$refs;
typedef struct _jc_polyglot_util_ErrorInfo$nonrefs	_jc_polyglot_util_ErrorInfo$nonrefs;
typedef struct _jc_polyglot_util_ErrorInfo$object	_jc_polyglot_util_ErrorInfo$object;

typedef struct _jc_polyglot_util_ErrorInfo$fields_struct	_jc_polyglot_util_ErrorInfo$fields_struct;
typedef const struct _jc_polyglot_util_ErrorInfo$vmethods	_jc_polyglot_util_ErrorInfo$vmethods;
typedef const struct _jc_polyglot_util_ErrorInfo$vtable	_jc_polyglot_util_ErrorInfo$vtable;
typedef const struct _jc_polyglot_util_ErrorInfo$vtype	_jc_polyglot_util_ErrorInfo$vtype;

// Class fields structure
struct _jc_polyglot_util_ErrorInfo$fields_struct {
	jint	INTERNAL__5fERROR;
	jint	IO__5fERROR;
	jint	LEXICAL__5fERROR;
	jint	SEMANTIC__5fERROR;
	jint	SYNTAX__5fERROR;
	jint	WARNING;
};
extern _jc_polyglot_util_ErrorInfo$fields_struct _jc_polyglot_util_ErrorInfo$class_fields;

// Constructors
extern void _jc_polyglot_util_ErrorInfo$method$_init$cdd55eca3cb7f7f4(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *, jint, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern jint _jc_polyglot_util_ErrorInfo$method$getErrorKind$88a3a6c2c6cb7265(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getErrorString$aa2623c57c93cc6c(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_util_ErrorInfo$method$getPosition$93950f582a09a82d(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getErrorKind$88a3a6c2c6cb7265;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getErrorString$aa2623c57c93cc6c;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getPosition$93950f582a09a82d;

// Static methods
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getErrorString$0e36df542c6f55a0(_jc_env *, jint);

// Virtual methods structure
struct _jc_polyglot_util_ErrorInfo$vmethods {
	jint	(*getErrorKind$88a3a6c2c6cb7265)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
	struct _jc_java_lang_String$object	*(*getErrorString$aa2623c57c93cc6c)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
	struct _jc_polyglot_util_Position$object	*(*getPosition$93950f582a09a82d)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *);
};

// Vtable
struct _jc_polyglot_util_ErrorInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_ErrorInfo$vmethods	polyglot_util_ErrorInfo;
};

// Vtype
struct _jc_polyglot_util_ErrorInfo$vtype {
	_jc_type			type;
	_jc_polyglot_util_ErrorInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ErrorInfo$sub_refs {
	struct _jc_java_lang_String$object	*message;
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_util_ErrorInfo$refs {
    _jc_polyglot_util_ErrorInfo$sub_refs	polyglot_util_ErrorInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ErrorInfo$sub_nonrefs {
	jint	kind;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ErrorInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_ErrorInfo$sub_nonrefs	polyglot_util_ErrorInfo;
};

// Object instance structure
struct _jc_polyglot_util_ErrorInfo$object {
	_jc_polyglot_util_ErrorInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ErrorInfo$vtype	*vtype;
	_jc_polyglot_util_ErrorInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ErrorInfo$vtype _jc_polyglot_util_ErrorInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ErrorInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ErrorInfo$class_object;

#endif	/* _JC_polyglot_util_ErrorInfo_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/ErrorInfo.h <==
// public class polyglot.util.ErrorInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1b61c050315c20e6 polyglot_util_ErrorInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_ErrorInfo_H_
#define _JC_polyglot_util_ErrorInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_util_ErrorInfo$sub_refs	_jc_polyglot_util_ErrorInfo$sub_refs;
typedef struct _jc_polyglot_util_ErrorInfo$sub_nonrefs	_jc_polyglot_util_ErrorInfo$sub_nonrefs;
typedef struct _jc_polyglot_util_ErrorInfo$refs	_jc_polyglot_util_ErrorInfo$refs;
typedef struct _jc_polyglot_util_ErrorInfo$nonrefs	_jc_polyglot_util_ErrorInfo$nonrefs;
typedef struct _jc_polyglot_util_ErrorInfo$object	_jc_polyglot_util_ErrorInfo$object;

typedef struct _jc_polyglot_util_ErrorInfo$fields_struct	_jc_polyglot_util_ErrorInfo$fields_struct;
typedef const struct _jc_polyglot_util_ErrorInfo$vmethods	_jc_polyglot_util_ErrorInfo$vmethods;
typedef const struct _jc_polyglot_util_ErrorInfo$vtable	_jc_polyglot_util_ErrorInfo$vtable;
typedef const struct _jc_polyglot_util_ErrorInfo$vtype	_jc_polyglot_util_ErrorInfo$vtype;

// Class fields structure
struct _jc_polyglot_util_ErrorInfo$fields_struct {
	jint	INTERNAL__5fERROR;
	jint	IO__5fERROR;
	jint	LEXICAL__5fERROR;
	jint	SEMANTIC__5fERROR;
	jint	SYNTAX__5fERROR;
	jint	WARNING;
};
extern _jc_polyglot_util_ErrorInfo$fields_struct _jc_polyglot_util_ErrorInfo$class_fields;

// Constructors
extern void _jc_polyglot_util_ErrorInfo$method$_init$cdd55eca3cb7f7f4(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *, jint, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_util_ErrorInfo$method$getErrorKind$88a3a6c2c6cb7265(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getErrorString$aa2623c57c93cc6c(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_util_ErrorInfo$method$getPosition$93950f582a09a82d(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getErrorKind$88a3a6c2c6cb7265;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getErrorString$aa2623c57c93cc6c;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_polyglot_util_ErrorInfo$method_info$getPosition$93950f582a09a82d;

// Static methods
extern struct _jc_java_lang_String$object *_jc_polyglot_util_ErrorInfo$method$getErrorString$0e36df542c6f55a0(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_ErrorInfo$vmethods {
	jint	(*getErrorKind$88a3a6c2c6cb7265)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getErrorString$aa2623c57c93cc6c)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_util_Position$object	*(*getPosition$93950f582a09a82d)(_jc_env *, struct _jc_polyglot_util_ErrorInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_ErrorInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_ErrorInfo$vmethods	polyglot_util_ErrorInfo;
};

// Vtype
struct _jc_polyglot_util_ErrorInfo$vtype {
	_jc_type			type;
	_jc_polyglot_util_ErrorInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_ErrorInfo$sub_refs {
	struct _jc_java_lang_String$object	*message;
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_util_ErrorInfo$refs {
    _jc_polyglot_util_ErrorInfo$sub_refs	polyglot_util_ErrorInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_ErrorInfo$sub_nonrefs {
	jint	kind;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_ErrorInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_ErrorInfo$sub_nonrefs	polyglot_util_ErrorInfo;
};

// Object instance structure
struct _jc_polyglot_util_ErrorInfo$object {
	_jc_polyglot_util_ErrorInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_ErrorInfo$vtype	*vtype;
	_jc_polyglot_util_ErrorInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_ErrorInfo$vtype _jc_polyglot_util_ErrorInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_ErrorInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_ErrorInfo$class_object;

#endif	/* _JC_polyglot_util_ErrorInfo_H_ */
